@@ -11,6 +11,7 @@ var createSlowWriteStream = utils.createSlowWriteStream
 var rawrequest = utils.rawrequest
 var request = utils.request
 var shouldHaveStatusMessage = utils.shouldHaveStatusMessage
+var shouldNotHaveBody = utils.shouldNotHaveBody
 var shouldNotHaveHeader = utils.shouldNotHaveHeader
 
 var describeStatusMessage = !/statusMessage/.test(http.IncomingMessage.toString())
@@ -21,7 +22,7 @@ describe('finalhandler(req, res)', function () {
   describe('headers', function () {
     it('should ignore err.headers without status code', function (done) {
       request(createServer(createError('oops!', {
-        headers: {'X-Custom-Header': 'foo'}
+        headers: { 'X-Custom-Header': 'foo' }
       })))
         .get('/')
         .expect(shouldNotHaveHeader('X-Custom-Header'))
@@ -30,7 +31,7 @@ describe('finalhandler(req, res)', function () {
 
     it('should ignore err.headers with invalid res.status', function (done) {
       request(createServer(createError('oops!', {
-        headers: {'X-Custom-Header': 'foo'},
+        headers: { 'X-Custom-Header': 'foo' },
         status: 601
       })))
         .get('/')
@@ -40,7 +41,7 @@ describe('finalhandler(req, res)', function () {
 
     it('should ignore err.headers with invalid res.statusCode', function (done) {
       request(createServer(createError('oops!', {
-        headers: {'X-Custom-Header': 'foo'},
+        headers: { 'X-Custom-Header': 'foo' },
         statusCode: 601
       })))
         .get('/')
@@ -50,7 +51,7 @@ describe('finalhandler(req, res)', function () {
 
     it('should include err.headers with err.status', function (done) {
       request(createServer(createError('oops!', {
-        headers: {'X-Custom-Header': 'foo=500', 'X-Custom-Header2': 'bar'},
+        headers: { 'X-Custom-Header': 'foo=500', 'X-Custom-Header2': 'bar' },
         status: 500
       })))
         .get('/')
@@ -61,7 +62,7 @@ describe('finalhandler(req, res)', function () {
 
     it('should include err.headers with err.statusCode', function (done) {
       request(createServer(createError('too many requests', {
-        headers: {'Retry-After': '5'},
+        headers: { 'Retry-After': '5' },
         statusCode: 429
       })))
         .get('/')
@@ -264,7 +265,9 @@ describe('finalhandler(req, res)', function () {
     it('should handle HEAD', function (done) {
       request(createServer())
         .head('/foo')
-        .expect(404, '', done)
+        .expect(404)
+        .expect(shouldNotHaveBody())
+        .end(done)
     })
 
     it('should include X-Content-Type-Options header', function (done) {
@@ -277,7 +280,7 @@ describe('finalhandler(req, res)', function () {
     it('should includeContent-Security-Policy header', function (done) {
       request(createServer())
         .get('/foo')
-        .expect('Content-Security-Policy', "default-src 'self'")
+        .expect('Content-Security-Policy', "default-src 'none'")
         .expect(404, done)
     })
 
@@ -302,7 +305,9 @@ describe('finalhandler(req, res)', function () {
     it('should handle HEAD', function (done) {
       request(createServer())
         .head('/foo')
-        .expect(404, '', done)
+        .expect(404)
+        .expect(shouldNotHaveBody())
+        .end(done)
     })
 
     it('should include X-Content-Type-Options header', function (done) {
@@ -315,7 +320,7 @@ describe('finalhandler(req, res)', function () {
     it('should includeContent-Security-Policy header', function (done) {
       request(createServer(createError('boom!')))
         .get('/foo')
-        .expect('Content-Security-Policy', "default-src 'self'")
+        .expect('Content-Security-Policy', "default-src 'none'")
         .expect(500, done)
     })
 
@@ -478,7 +483,7 @@ describe('finalhandler(req, res)', function () {
         process.nextTick(function () {
           done(createError('too many requests', {
             status: 429,
-            headers: {'Retry-After': '5'}
+            headers: { 'Retry-After': '5' }
           }))
           res.end('1')
         })
@@ -499,7 +504,7 @@ describe('finalhandler(req, res)', function () {
         error = e
       }
 
-      request(createServer(err, {onerror: log}))
+      request(createServer(err, { onerror: log }))
         .get('/')
         .end(function () {
           assert.equal(error, err)
